@@ -1,9 +1,9 @@
 #ifndef GPSFAKE_H
 #define GPSFAKE_H
 
-#include <QObject>
+#ifndef LIBLOCATION
 
-#ifndef Q_WS_MAEMO_5
+#include <QObject>
 
 class GpsMaemo5 : public QObject {
     Q_OBJECT
